pub unsafe extern "C" fn store_copy_path(
context: *mut c_context,
srcStore: *mut Store,
dstStore: *mut Store,
path: *const StorePath,
repair: bool,
checkSigs: bool,
) -> errExpand description
@brief Copy a path from one store to another.
@param[out] context Optional, stores error information @param[in] srcStore nix source store reference @param[in] dstStore nix destination store reference @param[in] path The path to copy @param[in] repair Whether to repair the path @param[in] checkSigs Whether to check path signatures are trusted before copying